.. _api_models:

======
Models
======

-------------------------
biomedsheets.models.Sheet
-------------------------

.. autoclass:: biomedsheets.models.Sheet
    :members:

-----------------------------
biomedsheets.models.BioEntity
-----------------------------

.. autoclass:: biomedsheets.models.BioEntity
    :members:

-----------------------------
biomedsheets.models.BioSample
-----------------------------

.. autoclass:: biomedsheets.models.BioSample
    :members:

------------------------------
biomedsheets.models.TestSample
------------------------------

.. autoclass:: biomedsheets.models.TestSample
    :members:

------------------------------
biomedsheets.models.NGSLibrary
------------------------------

.. autoclass:: biomedsheets.models.NGSLibrary
    :members:

------------------------------
biomedsheets.models.CrawlMixin
------------------------------

.. autoclass:: biomedsheets.models.CrawlMixin
    :members:
